Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1737)

Unified Diff: net/base/cookie_monster.h

Issue 5318002: Also register read cookies in the content settings delegate. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: updates Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/cookie_monster.h
diff --git a/net/base/cookie_monster.h b/net/base/cookie_monster.h
index 44bd51080fdeba6db669a0462f053678b2d90fd6..a43c27d8e473f2cf9d369895a76b07659639ce57 100644
--- a/net/base/cookie_monster.h
+++ b/net/base/cookie_monster.h
@@ -169,10 +169,15 @@ class CookieMonster : public CookieStore {
CookieList GetAllCookies();
// Returns all the cookies, for use in management UI, etc. Filters results
// using given url scheme, host / domain and path. This does not mark the
// cookies as having been accessed.
// The returned cookies are ordered by longest path, then earliest
// creation date.
+ CookieList GetAllCookiesForURLWithOptions(const GURL& url,
+ const CookieOptions& options);
+
+ // Invokes GetAllCookiesForURLWithOptions with options set to include HTTP
+ // only cookies.
CookieList GetAllCookiesForURL(const GURL& url);
// Deletes all of the cookies.
@@ -169,10 +169,15 @@ class CookieMonster : public CookieStore {
CookieList GetAllCookies();
// Returns all the cookies, for use in management UI, etc. Filters results
- // using given url scheme, host / domain and path. This does not mark the
- // cookies as having been accessed.
+ // using given url scheme, host / domain and path and options. This does not
+ // mark the cookies as having been accessed.
// The returned cookies are ordered by longest path, then earliest
// creation date.

Powered by Google App Engine
This is Rietveld 408576698